@@ -11,16 +11,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-//go:build openbsd && !amd64 && !nodiskstats
-// +build openbsd,!amd64,!nodiskstats
+//go:build !nodiskstats && !amd64
+// +build !nodiskstats,!amd64
 
 package collector
 
 import (
 	"fmt"
+	"log/slog"
 	"unsafe"
 
-	"github.com/go-kit/log"
 	"github.com/prometheus/client_golang/prometheus"
 	"golang.org/x/sys/unix"
 )
@@ -41,7 +41,7 @@ type diskstatsCollector struct {
 	time   typedDesc
 
 	deviceFilter deviceFilter
-	logger       log.Logger
+	logger       *slog.Logger
 }
 
 func init() {
@@ -49,7 +49,7 @@ func init() {
 }
 
 // NewDiskstatsCollector returns a new Collector exposing disk device stats.
-func NewDiskstatsCollector(logger log.Logger) (Collector, error) {
+func NewDiskstatsCollector(logger *slog.Logger) (Collector, error) {
 	deviceFilter, err := newDiskstatsDeviceFilter(logger)
 	if err != nil {
 		return nil, fmt.Errorf("failed to parse device filter flags: %w", err)
