@@ -11,22 +11,25 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+//go:build !noipvs
+// +build !noipvs
+
 package collector
 
 import (
 	"errors"
 	"fmt"
+	"io"
+	"log/slog"
 	"net/http"
 	"net/http/httptest"
 	"os"
 	"strings"
 	"testing"
 
-	"github.com/go-kit/log"
-
+	"github.com/alecthomas/kingpin/v2"
 	"github.com/prometheus/client_golang/prometheus"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
-	"gopkg.in/alecthomas/kingpin.v2"
 )
 
 func TestIPVSCollector(t *testing.T) {
@@ -111,7 +114,7 @@ func TestIPVSCollector(t *testing.T) {
 			if _, err := kingpin.CommandLine.Parse(args); err != nil {
 				t.Fatal(err)
 			}
-			collector, err := newIPVSCollector(log.NewNopLogger())
+			collector, err := newIPVSCollector(slog.New(slog.NewTextHandler(io.Discard, nil)))
 			if err != nil {
 				if test.err == nil {
 					t.Fatal(err)
@@ -179,7 +182,7 @@ func TestIPVSCollectorResponse(t *testing.T) {
 			if _, err := kingpin.CommandLine.Parse(args); err != nil {
 				t.Fatal(err)
 			}
-			collector, err := NewIPVSCollector(log.NewNopLogger())
+			collector, err := NewIPVSCollector(slog.New(slog.NewTextHandler(io.Discard, nil)))
 			if err != nil {
 				t.Fatal(err)
 			}
@@ -209,9 +212,8 @@ func TestIPVSCollectorResponse(t *testing.T) {
 					if want == got {
 						// this is a line we are interested in, and it is correct
 						continue wantLoop
-					} else {
-						gotLinesIdx++
 					}
+					gotLinesIdx++
 				}
 				// if this point is reached, the line we want was missing
 				t.Fatalf("Missing expected output line(s), first missing line is %s", want)
