@@ -19,8 +19,8 @@ package collector
 
 import (
 	"fmt"
+	"log/slog"
 
-	"github.com/go-kit/log"
 	"github.com/prometheus/client_golang/prometheus"
 	"golang.org/x/sys/unix"
 )
@@ -33,7 +33,7 @@ type memoryCollector struct {
 	pageSize uint64
 	sysctls  []bsdSysctl
 	kvm      kvm
-	logger   log.Logger
+	logger   *slog.Logger
 }
 
 func init() {
@@ -41,7 +41,7 @@ func init() {
 }
 
 // NewMemoryCollector returns a new Collector exposing memory stats.
-func NewMemoryCollector(logger log.Logger) (Collector, error) {
+func NewMemoryCollector(logger *slog.Logger) (Collector, error) {
 	tmp32, err := unix.SysctlUint32("vm.stats.vm.v_page_size")
 	if err != nil {
 		return nil, fmt.Errorf("sysctl(vm.stats.vm.v_page_size) failed: %w", err)
@@ -87,6 +87,7 @@ func NewMemoryCollector(logger log.Logger) (Collector, error) {
 				description: "Locked in memory by user, mlock, etc",
 				mib:         "vm.stats.vm.v_user_wire_count",
 				conversion:  fromPage,
+				dataType:    bsdSysctlTypeCLong,
 			},
 			{
 				name:        "cache_bytes",
