@@ -11,23 +11,22 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-//go:build !nonetdev && (linux || freebsd || openbsd || dragonfly || darwin)
+//go:build !nonetdev && (linux || freebsd || openbsd || dragonfly || darwin || aix)
 // +build !nonetdev
-// +build linux freebsd openbsd dragonfly darwin
+// +build linux freebsd openbsd dragonfly darwin aix
 
 package collector
 
 import (
 	"errors"
 	"fmt"
+	"log/slog"
 	"net"
 	"strconv"
 	"sync"
 
-	"github.com/go-kit/log"
-	"github.com/go-kit/log/level"
+	"github.com/alecthomas/kingpin/v2"
 	"github.com/prometheus/client_golang/prometheus"
-	"gopkg.in/alecthomas/kingpin.v2"
 )
 
 var (
@@ -44,7 +43,7 @@ type netDevCollector struct {
 	deviceFilter     deviceFilter
 	metricDescsMutex sync.Mutex
 	metricDescs      map[string]*prometheus.Desc
-	logger           log.Logger
+	logger           *slog.Logger
 }
 
 type netDevStats map[string]map[string]uint64
@@ -54,10 +53,10 @@ func init() {
 }
 
 // NewNetDevCollector returns a new Collector exposing network device stats.
-func NewNetDevCollector(logger log.Logger) (Collector, error) {
+func NewNetDevCollector(logger *slog.Logger) (Collector, error) {
 	if *oldNetdevDeviceInclude != "" {
 		if *netdevDeviceInclude == "" {
-			level.Warn(logger).Log("msg", "--collector.netdev.device-whitelist is DEPRECATED and will be removed in 2.0.0, use --collector.netdev.device-include")
+			logger.Warn("--collector.netdev.device-whitelist is DEPRECATED and will be removed in 2.0.0, use --collector.netdev.device-include")
 			*netdevDeviceInclude = *oldNetdevDeviceInclude
 		} else {
 			return nil, errors.New("--collector.netdev.device-whitelist and --collector.netdev.device-include are mutually exclusive")
@@ -66,7 +65,7 @@ func NewNetDevCollector(logger log.Logger) (Collector, error) {
 
 	if *oldNetdevDeviceExclude != "" {
 		if *netdevDeviceExclude == "" {
-			level.Warn(logger).Log("msg", "--collector.netdev.device-blacklist is DEPRECATED and will be removed in 2.0.0, use --collector.netdev.device-exclude")
+			logger.Warn("--collector.netdev.device-blacklist is DEPRECATED and will be removed in 2.0.0, use --collector.netdev.device-exclude")
 			*netdevDeviceExclude = *oldNetdevDeviceExclude
 		} else {
 			return nil, errors.New("--collector.netdev.device-blacklist and --collector.netdev.device-exclude are mutually exclusive")
@@ -78,11 +77,11 @@ func NewNetDevCollector(logger log.Logger) (Collector, error) {
 	}
 
 	if *netdevDeviceExclude != "" {
-		level.Info(logger).Log("msg", "Parsed flag --collector.netdev.device-exclude", "flag", *netdevDeviceExclude)
+		logger.Info("Parsed flag --collector.netdev.device-exclude", "flag", *netdevDeviceExclude)
 	}
 
 	if *netdevDeviceInclude != "" {
-		level.Info(logger).Log("msg", "Parsed Flag --collector.netdev.device-include", "flag", *netdevDeviceInclude)
+		logger.Info("Parsed Flag --collector.netdev.device-include", "flag", *netdevDeviceInclude)
 	}
 
 	return &netDevCollector{
@@ -93,7 +92,7 @@ func NewNetDevCollector(logger log.Logger) (Collector, error) {
 	}, nil
 }
 
-func (c *netDevCollector) metricDesc(key string) *prometheus.Desc {
+func (c *netDevCollector) metricDesc(key string, labels []string) *prometheus.Desc {
 	c.metricDescsMutex.Lock()
 	defer c.metricDescsMutex.Unlock()
 
@@ -101,7 +100,7 @@ func (c *netDevCollector) metricDesc(key string) *prometheus.Desc {
 		c.metricDescs[key] = prometheus.NewDesc(
 			prometheus.BuildFQName(namespace, c.subsystem, key+"_total"),
 			fmt.Sprintf("Network device statistic %s.", key),
-			[]string{"device"},
+			labels,
 			nil,
 		)
 	}
@@ -114,13 +113,29 @@ func (c *netDevCollector) Update(ch chan<- prometheus.Metric) error {
 	if err != nil {
 		return fmt.Errorf("couldn't get netstats: %w", err)
 	}
+
+	netDevLabels, err := getNetDevLabels()
+	if err != nil {
+		return fmt.Errorf("couldn't get netdev labels: %w", err)
+	}
+
 	for dev, devStats := range netDev {
 		if !*netdevDetailedMetrics {
 			legacy(devStats)
 		}
+
+		labels := []string{"device"}
+		labelValues := []string{dev}
+		if devLabels, exists := netDevLabels[dev]; exists {
+			for labelName, labelValue := range devLabels {
+				labels = append(labels, labelName)
+				labelValues = append(labelValues, labelValue)
+			}
+		}
+
 		for key, value := range devStats {
-			desc := c.metricDesc(key)
-			ch <- prometheus.MustNewConstMetric(desc, prometheus.CounterValue, float64(value), dev)
+			desc := c.metricDesc(key, labels)
+			ch <- prometheus.MustNewConstMetric(desc, prometheus.CounterValue, float64(value), labelValues...)
 		}
 	}
 	if *netdevAddressInfo {
