@@ -11,20 +11,20 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-//go:build !noprocesses
-// +build !noprocesses
+//go:build !noperf
+// +build !noperf
 
 package collector
 
 import (
+	"io"
+	"log/slog"
 	"os"
 	"runtime"
 	"strconv"
 	"strings"
 	"testing"
 
-	"github.com/go-kit/log"
-
 	"github.com/prometheus/client_golang/prometheus"
 )
 
@@ -45,7 +45,7 @@ func canTestPerf(t *testing.T) {
 
 func TestPerfCollector(t *testing.T) {
 	canTestPerf(t)
-	collector, err := NewPerfCollector(log.NewNopLogger())
+	collector, err := NewPerfCollector(slog.New(slog.NewTextHandler(io.Discard, nil)))
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -54,7 +54,9 @@ func TestPerfCollector(t *testing.T) {
 	metrics := make(chan prometheus.Metric)
 	defer close(metrics)
 	go func() {
+		i := 0
 		for range metrics {
+			i++
 		}
 	}()
 	if err := collector.Update(metrics); err != nil {
@@ -96,7 +98,7 @@ func TestPerfCollectorStride(t *testing.T) {
 				}
 			}
 			perfCPUsFlag = &test.flag
-			collector, err := NewPerfCollector(log.NewNopLogger())
+			collector, err := NewPerfCollector(slog.New(slog.NewTextHandler(io.Discard, nil)))
 			if err != nil {
 				t.Fatal(err)
 			}
