@@ -19,21 +19,20 @@ package collector
 import (
 	"errors"
 	"fmt"
+	"log/slog"
 	"os"
 	"strconv"
 
-	"github.com/go-kit/log"
-	"github.com/go-kit/log/level"
+	"github.com/alecthomas/kingpin/v2"
 	"github.com/prometheus/client_golang/prometheus"
 	"github.com/prometheus/procfs/sysfs"
-	"gopkg.in/alecthomas/kingpin.v2"
 )
 
 const raplCollectorSubsystem = "rapl"
 
 type raplCollector struct {
 	fs     sysfs.FS
-	logger log.Logger
+	logger *slog.Logger
 
 	joulesMetricDesc *prometheus.Desc
 }
@@ -47,7 +46,7 @@ var (
 )
 
 // NewRaplCollector returns a new Collector exposing RAPL metrics.
-func NewRaplCollector(logger log.Logger) (Collector, error) {
+func NewRaplCollector(logger *slog.Logger) (Collector, error) {
 	fs, err := sysfs.NewFS(*sysPath)
 
 	if err != nil {
@@ -74,11 +73,11 @@ func (c *raplCollector) Update(ch chan<- prometheus.Metric) error {
 	zones, err := sysfs.GetRaplZones(c.fs)
 	if err != nil {
 		if errors.Is(err, os.ErrNotExist) {
-			level.Debug(c.logger).Log("msg", "Platform doesn't have powercap files present", "err", err)
+			c.logger.Debug("Platform doesn't have powercap files present", "err", err)
 			return ErrNoData
 		}
 		if errors.Is(err, os.ErrPermission) {
-			level.Debug(c.logger).Log("msg", "Can't access powercap files", "err", err)
+			c.logger.Debug("Can't access powercap files", "err", err)
 			return ErrNoData
 		}
 		return fmt.Errorf("failed to retrieve rapl stats: %w", err)
@@ -88,7 +87,7 @@ func (c *raplCollector) Update(ch chan<- prometheus.Metric) error {
 		microJoules, err := rz.GetEnergyMicrojoules()
 		if err != nil {
 			if errors.Is(err, os.ErrPermission) {
-				level.Debug(c.logger).Log("msg", "Can't access energy_uj file", "zone", rz, "err", err)
+				c.logger.Debug("Can't access energy_uj file", "zone", rz, "err", err)
 				return ErrNoData
 			}
 			return err
